@@ -13,14 +13,17 @@
 #include <stdlib.h>
 
 #include "soup-auth-domain-digest.h"
-#include "soup.h"
 #include "soup-auth-digest.h"
+#include "soup-headers.h"
+#include "soup-marshal.h"
+#include "soup-message.h"
+#include "soup-uri.h"
 
 /**
  * SECTION:soup-auth-domain-digest
  * @short_description: Server-side "Digest" authentication
  *
- * #SoupAuthDomainDigest handles the server side of HTTP "Digest"
+ * #SoupAuthDomainBasic handles the server side of HTTP "Digest"
  * authentication.
  **/
 
@@ -44,13 +47,28 @@ typedef struct {
 
 G_DEFINE_TYPE (SoupAuthDomainDigest, soup_auth_domain_digest, SOUP_TYPE_AUTH_DOMAIN)
 
+static char    *accepts        (SoupAuthDomain *domain,
+				SoupMessage    *msg,
+				const char     *header);
+static char    *challenge      (SoupAuthDomain *domain,
+				SoupMessage    *msg);
+static gboolean check_password (SoupAuthDomain *domain,
+				SoupMessage    *msg,
+				const char     *username,
+				const char     *password);
+
+static void set_property (GObject *object, guint prop_id,
+			  const GValue *value, GParamSpec *pspec);
+static void get_property (GObject *object, guint prop_id,
+			  GValue *value, GParamSpec *pspec);
+
 static void
 soup_auth_domain_digest_init (SoupAuthDomainDigest *digest)
 {
 }
 
 static void
-soup_auth_domain_digest_finalize (GObject *object)
+finalize (GObject *object)
 {
 	SoupAuthDomainDigestPrivate *priv =
 		SOUP_AUTH_DOMAIN_DIGEST_GET_PRIVATE (object);
@@ -62,8 +80,51 @@ soup_auth_domain_digest_finalize (GObject *object)
 }
 
 static void
-soup_auth_domain_digest_set_property (GObject *object, guint prop_id,
-				      const GValue *value, GParamSpec *pspec)
+soup_auth_domain_digest_class_init (SoupAuthDomainDigestClass *digest_class)
+{
+	SoupAuthDomainClass *auth_domain_class =
+		SOUP_AUTH_DOMAIN_CLASS (digest_class);
+	GObjectClass *object_class = G_OBJECT_CLASS (digest_class);
+
+	g_type_class_add_private (digest_class, sizeof (SoupAuthDomainDigestPrivate));
+
+	auth_domain_class->accepts        = accepts;
+	auth_domain_class->challenge      = challenge;
+	auth_domain_class->check_password = check_password;
+
+	object_class->finalize     = finalize;
+	object_class->set_property = set_property;
+	object_class->get_property = get_property;
+
+	/**
+	 * SOUP_AUTH_DOMAIN_DIGEST_AUTH_CALLBACK:
+	 *
+	 * Alias for the #SoupAuthDomainDigest:auth-callback property.
+	 * (The #SoupAuthDomainDigestAuthCallback.)
+	 **/
+	g_object_class_install_property (
+		object_class, PROP_AUTH_CALLBACK,
+		g_param_spec_pointer (SOUP_AUTH_DOMAIN_DIGEST_AUTH_CALLBACK,
+				      "Authentication callback",
+				      "Password-finding callback",
+				      G_PARAM_READWRITE));
+	/**
+	 * SOUP_AUTH_DOMAIN_DIGEST_AUTH_DATA:
+	 *
+	 * Alias for the #SoupAuthDomainDigest:auth-callback property.
+	 * (The #SoupAuthDomainDigestAuthCallback.)
+	 **/
+	g_object_class_install_property (
+		object_class, PROP_AUTH_DATA,
+		g_param_spec_pointer (SOUP_AUTH_DOMAIN_DIGEST_AUTH_DATA,
+				      "Authentication callback data",
+				      "Data to pass to authentication callback",
+				      G_PARAM_READWRITE));
+}
+
+static void
+set_property (GObject *object, guint prop_id,
+	      const GValue *value, GParamSpec *pspec)
 {
 	SoupAuthDomainDigestPrivate *priv =
 		SOUP_AUTH_DOMAIN_DIGEST_GET_PRIVATE (object);
@@ -86,8 +147,8 @@ soup_auth_domain_digest_set_property (GObject *object, guint prop_id,
 }
 
 static void
-soup_auth_domain_digest_get_property (GObject *object, guint prop_id,
-				      GValue *value, GParamSpec *pspec)
+get_property (GObject *object, guint prop_id,
+	      GValue *value, GParamSpec *pspec)
 {
 	SoupAuthDomainDigestPrivate *priv =
 		SOUP_AUTH_DOMAIN_DIGEST_GET_PRIVATE (object);
@@ -145,9 +206,8 @@ soup_auth_domain_digest_new (const char *optname1, ...)
  * and return the corresponding encoded password (see
  * soup_auth_domain_digest_encode_password()).
  *
- * Return value: (nullable): the encoded password, or %NULL if
- * @username is not a valid user. @domain will free the password when
- * it is done with it.
+ * Return value: the encoded password, or %NULL if @username is not a
+ * valid user. @domain will free the password when it is done with it.
  **/
 
 /**
@@ -265,8 +325,7 @@ check_hex_urp (SoupAuthDomain *domain, SoupMessage *msg,
 }
 
 static char *
-soup_auth_domain_digest_accepts (SoupAuthDomain *domain, SoupMessage *msg,
-				 const char *header)
+accepts (SoupAuthDomain *domain, SoupMessage *msg, const char *header)
 {
 	SoupAuthDomainDigestPrivate *priv =
 		SOUP_AUTH_DOMAIN_DIGEST_GET_PRIVATE (domain);
@@ -310,7 +369,7 @@ soup_auth_domain_digest_accepts (SoupAuthDomain *domain, SoupMessage *msg,
 }
 
 static char *
-soup_auth_domain_digest_challenge (SoupAuthDomain *domain, SoupMessage *msg)
+challenge (SoupAuthDomain *domain, SoupMessage *msg)
 {
 	GString *str;
 
@@ -359,10 +418,10 @@ soup_auth_domain_digest_encode_password (const char *username,
 }
 
 static gboolean
-soup_auth_domain_digest_check_password (SoupAuthDomain *domain,
-					SoupMessage    *msg,
-					const char     *username,
-					const char     *password)
+check_password (SoupAuthDomain *domain,
+		SoupMessage    *msg,
+		const char     *username,
+		const char     *password)
 {
 	const char *header;
 	GHashTable *params;
@@ -392,46 +451,3 @@ soup_auth_domain_digest_check_password (SoupAuthDomain *domain,
 	soup_header_free_param_list (params);
 	return accept;
 }
-
-static void
-soup_auth_domain_digest_class_init (SoupAuthDomainDigestClass *digest_class)
-{
-	SoupAuthDomainClass *auth_domain_class =
-		SOUP_AUTH_DOMAIN_CLASS (digest_class);
-	GObjectClass *object_class = G_OBJECT_CLASS (digest_class);
-
-	g_type_class_add_private (digest_class, sizeof (SoupAuthDomainDigestPrivate));
-
-	auth_domain_class->accepts        = soup_auth_domain_digest_accepts;
-	auth_domain_class->challenge      = soup_auth_domain_digest_challenge;
-	auth_domain_class->check_password = soup_auth_domain_digest_check_password;
-
-	object_class->finalize     = soup_auth_domain_digest_finalize;
-	object_class->set_property = soup_auth_domain_digest_set_property;
-	object_class->get_property = soup_auth_domain_digest_get_property;
-
-	/**
-	 * SOUP_AUTH_DOMAIN_DIGEST_AUTH_CALLBACK:
-	 *
-	 * Alias for the #SoupAuthDomainDigest:auth-callback property.
-	 * (The #SoupAuthDomainDigestAuthCallback.)
-	 **/
-	g_object_class_install_property (
-		object_class, PROP_AUTH_CALLBACK,
-		g_param_spec_pointer (SOUP_AUTH_DOMAIN_DIGEST_AUTH_CALLBACK,
-				      "Authentication callback",
-				      "Password-finding callback",
-				      G_PARAM_READWRITE));
-	/**
-	 * SOUP_AUTH_DOMAIN_DIGEST_AUTH_DATA:
-	 *
-	 * Alias for the #SoupAuthDomainDigest:auth-callback property.
-	 * (The #SoupAuthDomainDigestAuthCallback.)
-	 **/
-	g_object_class_install_property (
-		object_class, PROP_AUTH_DATA,
-		g_param_spec_pointer (SOUP_AUTH_DOMAIN_DIGEST_AUTH_DATA,
-				      "Authentication callback data",
-				      "Data to pass to authentication callback",
-				      G_PARAM_READWRITE));
-}
