@@ -9,11 +9,16 @@
 #include <config.h>
 #endif
 
+#define LIBSOUP_I_HAVE_READ_BUG_594377_AND_KNOW_SOUP_PASSWORD_MANAGER_MIGHT_GO_AWAY
+
 #include <string.h>
 
 #include "soup-auth.h"
-#include "soup.h"
-#include "soup-connection-auth.h"
+#include "soup-auth-basic.h"
+#include "soup-auth-digest.h"
+#include "soup-headers.h"
+#include "soup-marshal.h"
+#include "soup-uri.h"
 
 /**
  * SECTION:soup-auth
@@ -37,9 +42,19 @@
 typedef struct {
 	gboolean proxy;
 	char *host;
-} SoupAuthPrivate;
 
-G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (SoupAuth, soup_auth, G_TYPE_OBJECT)
+	GHashTable *saved_passwords;
+} SoupAuthPrivate;
+#define SOUP_AUTH_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SOUP_TYPE_AUTH, SoupAuthPrivate))
+
+G_DEFINE_ABSTRACT_TYPE (SoupAuth, soup_auth, G_TYPE_OBJECT)
+
+enum {
+	SAVE_PASSWORD,
+	LAST_SIGNAL
+};
+
+static guint signals[LAST_SIGNAL] = { 0 };
 
 enum {
 	PROP_0,
@@ -53,37 +68,145 @@ enum {
 	LAST_PROP
 };
 
+static void set_property (GObject *object, guint prop_id,
+			  const GValue *value, GParamSpec *pspec);
+static void get_property (GObject *object, guint prop_id,
+			  GValue *value, GParamSpec *pspec);
+
+static void
+finalize (GObject *object)
+{
+	SoupAuth *auth = SOUP_AUTH (object);
+	SoupAuthPrivate *priv = SOUP_AUTH_GET_PRIVATE (auth);
+
+	g_free (auth->realm);
+	g_free (priv->host);
+	if (priv->saved_passwords)
+		g_hash_table_destroy (priv->saved_passwords);
+
+	G_OBJECT_CLASS (soup_auth_parent_class)->finalize (object);
+}
+
+static void
+soup_auth_class_init (SoupAuthClass *auth_class)
+{
+	GObjectClass *object_class = G_OBJECT_CLASS (auth_class);
+
+	g_type_class_add_private (auth_class, sizeof (SoupAuthPrivate));
+
+	object_class->finalize = finalize;
+	object_class->set_property = set_property;
+	object_class->get_property = get_property;
+
+	/**
+	 * SoupAuth::save-password:
+	 * @auth: the auth
+	 * @username: the username to save
+	 * @password: the password to save
+	 *
+	 * Emitted to request that the @username/@password pair be
+	 * saved. If the session supports password-saving, it will
+	 * connect to this signal before emitting
+	 * #SoupSession::authenticate, so that it record the password
+	 * if requested by the caller.
+	 *
+	 * Since: 2.28
+	 **/
+	signals[SAVE_PASSWORD] =
+		g_signal_new ("save-password",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_FIRST,
+			      0, NULL, NULL,
+			      _soup_marshal_NONE__STRING_STRING,
+			      G_TYPE_NONE, 2,
+			      G_TYPE_STRING,
+			      G_TYPE_STRING);
+
+	/* properties */
+	/**
+	 * SOUP_AUTH_SCHEME_NAME:
+	 *
+	 * An alias for the #SoupAuth:scheme-name property. (The
+	 * authentication scheme name.)
+	 **/
+	g_object_class_install_property (
+		object_class, PROP_SCHEME_NAME,
+		g_param_spec_string (SOUP_AUTH_SCHEME_NAME,
+				     "Scheme name",
+				     "Authentication scheme name",
+				     NULL,
+				     G_PARAM_READABLE));
+	/**
+	 * SOUP_AUTH_REALM:
+	 *
+	 * An alias for the #SoupAuth:realm property. (The
+	 * authentication realm.)
+	 **/
+	g_object_class_install_property (
+		object_class, PROP_REALM,
+		g_param_spec_string (SOUP_AUTH_REALM,
+				     "Realm",
+				     "Authentication realm",
+				     NULL,
+				     G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+	/**
+	 * SOUP_AUTH_HOST:
+	 *
+	 * An alias for the #SoupAuth:host property. (The
+	 * host being authenticated to.)
+	 **/
+	g_object_class_install_property (
+		object_class, PROP_HOST,
+		g_param_spec_string (SOUP_AUTH_HOST,
+				     "Host",
+				     "Authentication host",
+				     NULL,
+				     G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+	/**
+	 * SOUP_AUTH_IS_FOR_PROXY:
+	 *
+	 * An alias for the #SoupAuth:is-for-proxy property. (Whether
+	 * or not the auth is for a proxy server.)
+	 **/
+	g_object_class_install_property (
+		object_class, PROP_IS_FOR_PROXY,
+		g_param_spec_boolean (SOUP_AUTH_IS_FOR_PROXY,
+				      "For Proxy",
+				      "Whether or not the auth is for a proxy server",
+				      FALSE,
+				      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+	/**
+	 * SOUP_AUTH_IS_AUTHENTICATED:
+	 *
+	 * An alias for the #SoupAuth:is-authenticated property.
+	 * (Whether or not the auth has been authenticated.)
+	 **/
+	g_object_class_install_property (
+		object_class, PROP_IS_AUTHENTICATED,
+		g_param_spec_boolean (SOUP_AUTH_IS_AUTHENTICATED,
+				      "Authenticated",
+				      "Whether or not the auth is authenticated",
+				      FALSE,
+				      G_PARAM_READABLE));
+}
+
 static void
 soup_auth_init (SoupAuth *auth)
 {
 }
 
 static void
-soup_auth_finalize (GObject *object)
+set_property (GObject *object, guint prop_id,
+	      const GValue *value, GParamSpec *pspec)
 {
 	SoupAuth *auth = SOUP_AUTH (object);
-	SoupAuthPrivate *priv = soup_auth_get_instance_private (auth);
-
-	g_free (auth->realm);
-	g_free (priv->host);
-
-	G_OBJECT_CLASS (soup_auth_parent_class)->finalize (object);
-}
-
-static void
-soup_auth_set_property (GObject *object, guint prop_id,
-			const GValue *value, GParamSpec *pspec)
-{
-	SoupAuth *auth = SOUP_AUTH (object);
-	SoupAuthPrivate *priv = soup_auth_get_instance_private (auth);
+	SoupAuthPrivate *priv = SOUP_AUTH_GET_PRIVATE (object);
 
 	switch (prop_id) {
 	case PROP_REALM:
-		g_free (auth->realm);
 		auth->realm = g_value_dup_string (value);
 		break;
 	case PROP_HOST:
-		g_free (priv->host);
 		priv->host = g_value_dup_string (value);
 		break;
 	case PROP_IS_FOR_PROXY:
@@ -96,11 +219,11 @@ soup_auth_set_property (GObject *object, guint prop_id,
 }
 
 static void
-soup_auth_get_property (GObject *object, guint prop_id,
-			GValue *value, GParamSpec *pspec)
+get_property (GObject *object, guint prop_id,
+	      GValue *value, GParamSpec *pspec)
 {
 	SoupAuth *auth = SOUP_AUTH (object);
-	SoupAuthPrivate *priv = soup_auth_get_instance_private (auth);
+	SoupAuthPrivate *priv = SOUP_AUTH_GET_PRIVATE (object);
 
 	switch (prop_id) {
 	case PROP_SCHEME_NAME:
@@ -124,96 +247,6 @@ soup_auth_get_property (GObject *object, guint prop_id,
 	}
 }
 
-static gboolean
-auth_can_authenticate (SoupAuth *auth)
-{
-	return TRUE;
-}
-
-static void
-soup_auth_class_init (SoupAuthClass *auth_class)
-{
-	GObjectClass *object_class = G_OBJECT_CLASS (auth_class);
-
-	auth_class->can_authenticate = auth_can_authenticate;
-
-	object_class->finalize     = soup_auth_finalize;
-	object_class->set_property = soup_auth_set_property;
-	object_class->get_property = soup_auth_get_property;
-
-	/* properties */
-	/**
-	 * SOUP_AUTH_SCHEME_NAME:
-	 *
-	 * An alias for the #SoupAuth:scheme-name property. (The
-	 * authentication scheme name.)
-	 **/
-	g_object_class_install_property (
-		object_class, PROP_SCHEME_NAME,
-		g_param_spec_string (SOUP_AUTH_SCHEME_NAME,
-				     "Scheme name",
-				     "Authentication scheme name",
-				     NULL,
-				     G_PARAM_READABLE |
-				     G_PARAM_STATIC_STRINGS));
-	/**
-	 * SOUP_AUTH_REALM:
-	 *
-	 * An alias for the #SoupAuth:realm property. (The
-	 * authentication realm.)
-	 **/
-	g_object_class_install_property (
-		object_class, PROP_REALM,
-		g_param_spec_string (SOUP_AUTH_REALM,
-				     "Realm",
-				     "Authentication realm",
-				     NULL,
-				     G_PARAM_READWRITE |
-				     G_PARAM_STATIC_STRINGS));
-	/**
-	 * SOUP_AUTH_HOST:
-	 *
-	 * An alias for the #SoupAuth:host property. (The
-	 * host being authenticated to.)
-	 **/
-	g_object_class_install_property (
-		object_class, PROP_HOST,
-		g_param_spec_string (SOUP_AUTH_HOST,
-				     "Host",
-				     "Authentication host",
-				     NULL,
-				     G_PARAM_READWRITE |
-				     G_PARAM_STATIC_STRINGS));
-	/**
-	 * SOUP_AUTH_IS_FOR_PROXY:
-	 *
-	 * An alias for the #SoupAuth:is-for-proxy property. (Whether
-	 * or not the auth is for a proxy server.)
-	 **/
-	g_object_class_install_property (
-		object_class, PROP_IS_FOR_PROXY,
-		g_param_spec_boolean (SOUP_AUTH_IS_FOR_PROXY,
-				      "For Proxy",
-				      "Whether or not the auth is for a proxy server",
-				      FALSE,
-				      G_PARAM_READWRITE |
-				      G_PARAM_STATIC_STRINGS));
-	/**
-	 * SOUP_AUTH_IS_AUTHENTICATED:
-	 *
-	 * An alias for the #SoupAuth:is-authenticated property.
-	 * (Whether or not the auth has been authenticated.)
-	 **/
-	g_object_class_install_property (
-		object_class, PROP_IS_AUTHENTICATED,
-		g_param_spec_boolean (SOUP_AUTH_IS_AUTHENTICATED,
-				      "Authenticated",
-				      "Whether or not the auth is authenticated",
-				      FALSE,
-				      G_PARAM_READABLE |
-				      G_PARAM_STATIC_STRINGS));
-}
-
 /**
  * soup_auth_new:
  * @type: the type of auth to create (a subtype of #SoupAuth)
@@ -226,8 +259,8 @@ soup_auth_class_init (SoupAuthClass *auth_class)
  * This is called by #SoupSession; you will normally not create auths
  * yourself.
  *
- * Return value: (nullable): the new #SoupAuth, or %NULL if it could
- * not be created
+ * Return value: the new #SoupAuth, or %NULL if it could not be
+ * created
  **/
 SoupAuth *
 soup_auth_new (GType type, SoupMessage *msg, const char *auth_header)
@@ -252,12 +285,19 @@ soup_auth_new (GType type, SoupMessage *msg, const char *auth_header)
 	}
 
 	params = soup_header_parse_param_list (auth_header + strlen (scheme));
-	if (!params)
-		params = g_hash_table_new (NULL, NULL);
+	if (!params) {
+		g_object_unref (auth);
+		return NULL;
+	}
 
 	realm = g_hash_table_lookup (params, "realm");
-	if (realm)
-		auth->realm = g_strdup (realm);
+	if (!realm) {
+		soup_header_free_param_list (params);
+		g_object_unref (auth);
+		return NULL;
+	}
+
+	auth->realm = g_strdup (realm);
 
 	if (!SOUP_AUTH_GET_CLASS (auth)->update (auth, msg, params)) {
 		g_object_unref (auth);
@@ -298,10 +338,10 @@ soup_auth_update (SoupAuth *auth, SoupMessage *msg, const char *auth_header)
 
 	params = soup_header_parse_param_list (auth_header + strlen (scheme));
 	if (!params)
-		params = g_hash_table_new (NULL, NULL);
+		return FALSE;
 
 	realm = g_hash_table_lookup (params, "realm");
-	if (realm && auth->realm && strcmp (realm, auth->realm) != 0) {
+	if (!realm || strcmp (realm, auth->realm) != 0) {
 		soup_header_free_param_list (params);
 		return FALSE;
 	}
@@ -322,6 +362,9 @@ soup_auth_update (SoupAuth *auth, SoupMessage *msg, const char *auth_header)
  *
  * Call this on an auth to authenticate it; normally this will cause
  * the auth's message to be requeued with the new authentication info.
+ *
+ * This does not cause the password to be saved to persistent storage;
+ * see soup_auth_save_password() for that.
  **/
 void
 soup_auth_authenticate (SoupAuth *auth, const char *username, const char *password)
@@ -350,11 +393,9 @@ soup_auth_authenticate (SoupAuth *auth, const char *username, const char *passwo
 gboolean
 soup_auth_is_for_proxy (SoupAuth *auth)
 {
-	SoupAuthPrivate *priv = soup_auth_get_instance_private (auth);
-
 	g_return_val_if_fail (SOUP_IS_AUTH (auth), FALSE);
 
-	return priv->proxy;
+	return SOUP_AUTH_GET_PRIVATE (auth)->proxy;
 }
 
 /**
@@ -384,13 +425,12 @@ soup_auth_get_scheme_name (SoupAuth *auth)
 const char *
 soup_auth_get_host (SoupAuth *auth)
 {
-	SoupAuthPrivate *priv = soup_auth_get_instance_private (auth);
-
 	g_return_val_if_fail (SOUP_IS_AUTH (auth), NULL);
 
-	return priv->host;
+	return SOUP_AUTH_GET_PRIVATE (auth)->host;
 }
 
+
 /**
  * soup_auth_get_realm:
  * @auth: a #SoupAuth
@@ -426,13 +466,9 @@ soup_auth_get_info (SoupAuth *auth)
 {
 	g_return_val_if_fail (SOUP_IS_AUTH (auth), NULL);
 
-	if (SOUP_IS_CONNECTION_AUTH (auth))
-		return g_strdup (SOUP_AUTH_GET_CLASS (auth)->scheme_name);
-	else {
-		return g_strdup_printf ("%s:%s",
-					SOUP_AUTH_GET_CLASS (auth)->scheme_name,
-					auth->realm);
-	}
+	return g_strdup_printf ("%s:%s",
+				SOUP_AUTH_GET_CLASS (auth)->scheme_name,
+				auth->realm);
 }
 
 /**
@@ -471,52 +507,6 @@ soup_auth_get_authorization (SoupAuth *auth, SoupMessage *msg)
 	return SOUP_AUTH_GET_CLASS (auth)->get_authorization (auth, msg);
 }
 
-/**
- * soup_auth_is_ready:
- * @auth: a #SoupAuth
- * @msg: a #SoupMessage
- *
- * Tests if @auth is ready to make a request for @msg with. For most
- * auths, this is equivalent to soup_auth_is_authenticated(), but for
- * some auth types (eg, NTLM), the auth may be sendable (eg, as an
- * authentication request) even before it is authenticated.
- *
- * Return value: %TRUE if @auth is ready to make a request with.
- *
- * Since: 2.42
- **/
-gboolean
-soup_auth_is_ready (SoupAuth    *auth,
-		    SoupMessage *msg)
-{
-	g_return_val_if_fail (SOUP_IS_AUTH (auth), TRUE);
-	g_return_val_if_fail (SOUP_IS_MESSAGE (msg), TRUE);
-
-	if (SOUP_AUTH_GET_CLASS (auth)->is_ready)
-		return SOUP_AUTH_GET_CLASS (auth)->is_ready (auth, msg);
-	else
-		return SOUP_AUTH_GET_CLASS (auth)->is_authenticated (auth);
-}
-
-/**
- * soup_auth_can_authenticate:
- * @auth: a #SoupAuth
- *
- * Tests if @auth is able to authenticate by providing credentials to the
- * soup_auth_authenticate().
- *
- * Return value: %TRUE if @auth is able to accept credentials.
- *
- * Since: 2.54
- **/
-gboolean
-soup_auth_can_authenticate (SoupAuth *auth)
-{
-	g_return_val_if_fail (SOUP_IS_AUTH (auth), FALSE);
-
-	return SOUP_AUTH_GET_CLASS (auth)->can_authenticate (auth);
-}
-
 /**
  * soup_auth_get_protection_space:
  * @auth: a #SoupAuth
@@ -550,34 +540,143 @@ soup_auth_get_protection_space (SoupAuth *auth, SoupURI *source_uri)
 void
 soup_auth_free_protection_space (SoupAuth *auth, GSList *space)
 {
-	g_slist_free_full (space, g_free);
+	GSList *s;
+
+	for (s = space; s; s = s->next)
+		g_free (s->data);
+	g_slist_free (space);
 }
 
 /**
  * soup_auth_get_saved_users:
+ * @auth: a #SoupAuth
  *
- * Return value: (transfer full) (element-type utf8):
- */
+ * Gets a list of usernames for which a saved password is available.
+ * (If the session is not configured to save passwords, this will
+ * always be %NULL.)
+ *
+ * Return value: (transfer container): the list of usernames. You must
+ * free the list with g_slist_free(), but do not free or modify the
+ * contents.
+ *
+ * Since: 2.28
+ **/
 GSList *
 soup_auth_get_saved_users (SoupAuth *auth)
 {
-	return NULL;
+	SoupAuthPrivate *priv;
+	GSList *users;
+
+	g_return_val_if_fail (SOUP_IS_AUTH (auth), NULL);
+
+	priv = SOUP_AUTH_GET_PRIVATE (auth);
+	users = NULL;
+
+	if (priv->saved_passwords) {
+		GHashTableIter iter;
+		gpointer key, value;
+
+		g_hash_table_iter_init (&iter, priv->saved_passwords);
+		while (g_hash_table_iter_next (&iter, &key, &value))
+			users = g_slist_prepend (users, key);
+	}
+	return users;
 }
 
+/**
+ * soup_auth_get_saved_password:
+ * @auth: a #SoupAuth
+ * @user: a username from the list returned from
+ * soup_auth_get_saved_users().
+ *
+ * Given a username for which @auth has a saved password, this returns
+ * that password. If @auth doesn't have a passwords saved for @user, it
+ * returns %NULL.
+ *
+ * Return value: the saved password, or %NULL.
+ *
+ * Since: 2.28
+ **/
 const char *
 soup_auth_get_saved_password (SoupAuth *auth, const char *user)
 {
-	return NULL;
+	SoupAuthPrivate *priv;
+
+	g_return_val_if_fail (SOUP_IS_AUTH (auth), NULL);
+	g_return_val_if_fail (user != NULL, NULL);
+
+	priv = SOUP_AUTH_GET_PRIVATE (auth);
+	if (!priv->saved_passwords)
+		return NULL;
+	return g_hash_table_lookup (priv->saved_passwords, user);
 }
 
+static void
+free_password (gpointer password)
+{
+	memset (password, 0, strlen (password));
+	g_free (password);
+}
+
+static inline void
+init_saved_passwords (SoupAuthPrivate *priv)
+{
+	priv->saved_passwords = g_hash_table_new_full (
+		g_str_hash, g_str_equal, g_free, free_password);
+}
+
+/**
+ * soup_auth_has_saved_password:
+ * @auth: a #SoupAuth
+ * @username: a username
+ * @password: a password
+ *
+ * Updates @auth to be aware of an already-saved username/password
+ * combination. This method <emphasis>does not</emphasis> cause the
+ * given @username and @password to be saved; use
+ * soup_auth_save_password() for that. (soup_auth_has_saved_password()
+ * is an internal method, which is used by the code that actually
+ * saves and restores the passwords.)
+ *
+ * Since: 2.28
+ **/
 void
 soup_auth_has_saved_password (SoupAuth *auth, const char *username,
 			      const char *password)
 {
+	SoupAuthPrivate *priv;
+
+	g_return_if_fail (SOUP_IS_AUTH (auth));
+	g_return_if_fail (username != NULL);
+	g_return_if_fail (password != NULL);
+
+	priv = SOUP_AUTH_GET_PRIVATE (auth);
+
+	if (!priv->saved_passwords)
+		init_saved_passwords (priv);
+	g_hash_table_insert (priv->saved_passwords,
+			     g_strdup (username), g_strdup (password));
 }
 
+/**
+ * soup_auth_save_password:
+ * @auth: a #SoupAuth
+ * @username: the username provided by the user or client
+ * @password: the password provided by the user or client
+ *
+ * Requests that the username/password pair be saved to whatever form
+ * of persistent password storage the session supports.
+ *
+ * Since: 2.28
+ **/
 void
 soup_auth_save_password (SoupAuth *auth, const char *username,
 			 const char *password)
 {
+	g_return_if_fail (SOUP_IS_AUTH (auth));
+	g_return_if_fail (username != NULL);
+	g_return_if_fail (password != NULL);
+
+	g_signal_emit (auth, signals[SAVE_PASSWORD], 0,
+		       username, password);
 }
